package Net::Kubernetes::Resource::ReplicationController;
$Net::Kubernetes::Resource::ReplicationController::VERSION = '0.05';
use Moose;

=head1 NAME

Net::Kubernetes::Resource::ReplicationController

=head1 VERSION

version 0.05

=cut

extends 'Net::Kubernetes::Resource';
with 'Net::Kubernetes::Resource::State';
with 'Net::Kubernetes::Resource::Spec';

return 42;
